.. _Installation:

============
Installation
============


.. _Install:

PIP Install
-----------

dnacentersdk is available via PIP and the `Python Package Index (PyPI)`_.  To
install dnacentersdk, simply run this command from your terminal of choice:

.. code-block:: bash

    $ pip install dnacentersdk

The dnacentersdk package is distributed as a *source distribution* (no
binaries).


.. _Upgrade:

PIP Upgrade
-----------

To ensure that you have the latest version, check-for and install upgrades via
PIP:

.. code-block:: bash

    $ pip install dnacentersdk --upgrade


.. _Source Code:

Get the Source Code
-------------------

dnacentersdk is developed on GitHub.  If you like and use this package,
please take a few seconds to Star the package on
the `cisco-en-programmability/dnacentersdk`_ GitHub page.  Your feedback and
contributions are always welcome.

Use the following command to download the source code (GIT repository):

.. code-block:: bash

    $ git clone https://github.com/cisco-en-programmability/dnacentersdk.git

You can then install the package to your environment, with the following
command:

.. code-block:: bash

    $ python setup.py install


*Copyright (c) 2019 Cisco and/or its affiliates.*


.. _Python Package Index (PyPI): https://pypi.python.org/pypi/dnacentersdk
.. _cisco-en-programmability/dnacentersdk: https://github.com/cisco-en-programmability/dnacentersdk
